'use strict';

var _utils = require('./utils');

describe('utils', function () {
  var localStorageMock = void 0;
  beforeEach(function () {
    localStorageMock = {
      getItem: jest.fn(),
      removeItem: jest.fn(),
      setItem: jest.fn()
    };
  });

  describe('getItem', function () {
    it('calls getItem on the provided localStorage implementation', function () {
      (0, _utils.getItem)('key', localStorageMock);
      expect(localStorageMock.getItem.mock.calls.length).toBe(1);
      expect(localStorageMock.getItem.mock.calls[0]).toEqual(['key']);
    });

    it('returns empty string', function () {
      var emptyString = '';
      localStorageMock = {
        getItem: function getItem() {
          return emptyString;
        }
      };
      var result = (0, _utils.getItem)('key', localStorageMock);
      expect(result).toBe(emptyString);
    });

    it('returns non-empty string', function () {
      var stringValue = 'string';
      localStorageMock = {
        getItem: function getItem() {
          return stringValue;
        }
      };
      var result = (0, _utils.getItem)('key', localStorageMock);
      expect(result).toBe(stringValue);
    });

    it('returns boolean', function () {
      var booleanValue = false;
      localStorageMock = {
        getItem: function getItem() {
          return booleanValue;
        }
      };
      var result = (0, _utils.getItem)('key', localStorageMock);
      expect(result).toBe(booleanValue);
    });

    it('returns undefined', function () {
      var undefinedValue = undefined;
      localStorageMock = {
        getItem: function getItem() {
          return undefinedValue;
        }
      };
      var result = (0, _utils.getItem)('key', localStorageMock);
      expect(result).toBe(undefinedValue);
    });

    it('returns null', function () {
      var nullValue = null;
      localStorageMock = {
        getItem: function getItem() {
          return nullValue;
        }
      };
      var result = (0, _utils.getItem)('key', localStorageMock);
      expect(result).toBe(nullValue);
    });

    it('returns object', function () {
      var objectValue = {
        name: {
          first: 'first',
          last: 'last'
        },
        verified: true
      };
      localStorageMock = {
        getItem: function getItem() {
          return JSON.stringify(objectValue);
        }
      };
      var result = (0, _utils.getItem)('key', localStorageMock);
      expect(result).toEqual(objectValue);
    });
  });

  describe('removeItem', function () {
    it('calls removeItem on the provided localStorage implementation', function () {
      (0, _utils.removeItem)('key', localStorageMock);
      expect(localStorageMock.removeItem.mock.calls.length).toBe(1);
      expect(localStorageMock.removeItem.mock.calls[0]).toEqual(['key']);
    });
  });

  describe('setItem', function () {
    it('calls setItem on the provided localStorage implementation', function () {
      var key = 'key';
      var value = 'value';
      var stringifiedValue = JSON.stringify(value);
      (0, _utils.setItem)(key, value, localStorageMock);
      expect(localStorageMock.setItem.mock.calls.length).toBe(1);
      expect(localStorageMock.setItem.mock.calls[0]).toEqual(['key', stringifiedValue]);
    });

    it('calls setItem with a stringified object', function () {
      var key = 'user';
      var value = {
        age: 31,
        name: {
          first: 'first',
          last: 'last'
        },
        email: undefined,
        address: null,
        verified: true
      };
      var stringifiedValue = JSON.stringify(value);

      (0, _utils.setItem)(key, value, localStorageMock);

      expect(localStorageMock.setItem.mock.calls.length).toBe(1);
      expect(localStorageMock.setItem.mock.calls[0]).toEqual([key, stringifiedValue]);
    });
  });
});